#!/usr/bin/env python3
from troposphere import Template
from troposphere.redshiftserverless import ConfigParameter, Namespace, Workgroup

# Redshift serverless cluster variables
admin_username = "{{{{resolve:ssm:/redshift_admin_username}}}}"
admin_password = "{{{{resolve:ssm:/redshift_admin_password}}}}"
default_iam_role_arn = "arn:aws:iam::123456789123:role/service-role/AmazonRedshift-CommandsAccessRole-123451234512345"
default_db_name = "dev"
iam_roles = []
serverless_namespace_name = "serverless"
tcp_port = 5439
vpc_id = "vpc-12345678123456789"
subnet_ids = ["subnet-12345678912345678", "subnet-98765432198765432"]
security_group_ids = ["sg-12345123451234567"]

# Prepare Template
t = Template()
t.set_description("RedshiftServerless: Template and module example")

RedshiftServerlessNamespace = t.add_resource(
    Namespace(
        "RedshiftServerlessNamespace",
        AdminUsername=admin_username,
        AdminUserPassword=admin_password,
        DbName=default_db_name,
        DefaultIamRoleArn=default_iam_role_arn,
        IamRoles=iam_roles,
        NamespaceName=serverless_namespace_name,
    )
)

RedshiftServerlessWorkgroup = t.add_resource(
    Workgroup(
        "RedshiftServerlessWorkgroup",
        ConfigParameters=[
            ConfigParameter(
                ParameterKey="enable_user_activity_logging", ParameterValue="true"
            )
        ],
        EnhancedVpcRouting=True,
        NamespaceName=serverless_namespace_name,
        PubliclyAccessible=False,
        SecurityGroupIds=security_group_ids,
        SubnetIds=subnet_ids,
        WorkgroupName="RedshiftServerlessWorkgroup",
    )
)

# Output all necessary files with the template and stack_details
print(t.to_json())



import unittest

from troposphere import Parameter, Ref


class TestInitArguments(unittest.TestCase):
    def test_title_max_length(self):
        title = "i" * 256
        with self.assertRaises(ValueError):
            Parameter(title, Type="String")

    def test_ref_can_be_requested(self):
        param = Parameter("title", Type="String")
        reference = param.ref()

        self.assertIsInstance(reference, Ref)
        self.assertDictEqual(reference.data, {"Ref": "title"})


class TestParameterValidator(unittest.TestCase):
    def test_allowed_pattern_for_number(self):
        with self.assertRaises(ValueError):
            Parameter("Foo", Type="Number", AllowedPattern="^[a-zA-Z0-9]*$").validate()

    def test_allowed_pattern_for_comma_delimited_list_and_string(self):
        Parameter(
            "Foo",
            Type="CommaDelimitedList",
            AllowedPattern="^[A-Z]{2}$",
            Default="",
        ).validate()

        Parameter(
            "Foo",
            Type="String",
            AllowedPattern="^[A-Z]{2}$",
            Default="",
        ).validate()

    def test_aws_specific_type(self):
        Parameter(
            "Foo",
            Type="AWS::EC2::KeyPair::KeyName",
            Default="",
        ).validate()


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from . import integer_range, json_checker, positive_integer, tags_or_list


def dict_or_string(x):
    """
    Property: Model.Schema
    """

    if isinstance(x, (dict, str)):
        return x
    raise TypeError(f"Value {x} of type {type(x)} must be either dict or str")


def validate_tags_or_list(x):
    """
    Property: StageDescription.Tags
    Property: Stage.Tags
    """
    return tags_or_list(x)


def validate_timeout_in_millis(x):
    """
    Property: Integration.TimeoutInMillis
    """
    return integer_range(50, 29000)(x)


def validate_authorizer_ttl(ttl_value):
    """Validate authorizer ttl timeout
    :param ttl_value: The TTL timeout in seconds
    :return: The provided TTL value if valid
    Property: Authorizer.AuthorizerResultTtlInSeconds
    """
    ttl_value = int(positive_integer(ttl_value))
    if ttl_value > 3600:
        raise ValueError("The AuthorizerResultTtlInSeconds should be <= 3600")
    return ttl_value


def validate_gateway_response_type(response_type):
    """Validate response type
    :param response_type: The GatewayResponse response type
    :return: The provided value if valid
    Property: GatewayResponse.ResponseType
    """
    valid_response_types = [
        "ACCESS_DENIED",
        "API_CONFIGURATION_ERROR",
        "AUTHORIZER_FAILURE",
        "AUTHORIZER_CONFIGURATION_ERROR",
        "BAD_REQUEST_PARAMETERS",
        "BAD_REQUEST_BODY",
        "DEFAULT_4XX",
        "DEFAULT_5XX",
        "EXPIRED_TOKEN",
        "INVALID_SIGNATURE",
        "INTEGRATION_FAILURE",
        "INTEGRATION_TIMEOUT",
        "INVALID_API_KEY",
        "MISSING_AUTHENTICATION_TOKEN",
        "QUOTA_EXCEEDED",
        "REQUEST_TOO_LARGE",
        "RESOURCE_NOT_FOUND",
        "THROTTLED",
        "UNAUTHORIZED",
        "UNSUPPORTED_MEDIA_TYPE",
    ]
    if response_type not in valid_response_types:
        raise ValueError("{} is not a valid ResponseType".format(response_type))
    return response_type


def validate_model(self):
    """
    Class: Model
    """
    name = "Schema"
    if name in self.properties:
        schema = self.properties.get(name)
        self.properties[name] = json_checker(schema)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double, integer


class LocalHealthEventsConfig(AWSProperty):
    """
    `LocalHealthEventsConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-internetmonitor-monitor-localhealtheventsconfig.html>`__
    """

    props: PropsDictType = {
        "HealthScoreThreshold": (double, False),
        "MinTrafficImpact": (double, False),
        "Status": (str, False),
    }


class HealthEventsConfig(AWSProperty):
    """
    `HealthEventsConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-internetmonitor-monitor-healtheventsconfig.html>`__
    """

    props: PropsDictType = {
        "AvailabilityLocalHealthEventsConfig": (LocalHealthEventsConfig, False),
        "AvailabilityScoreThreshold": (double, False),
        "PerformanceLocalHealthEventsConfig": (LocalHealthEventsConfig, False),
        "PerformanceScoreThreshold": (double, False),
    }


class S3Config(AWSProperty):
    """
    `S3Config <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-internetmonitor-monitor-s3config.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, False),
        "BucketPrefix": (str, False),
        "LogDeliveryStatus": (str, False),
    }


class InternetMeasurementsLogDelivery(AWSProperty):
    """
    `InternetMeasurementsLogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-internetmonitor-monitor-internetmeasurementslogdelivery.html>`__
    """

    props: PropsDictType = {
        "S3Config": (S3Config, False),
    }


class Monitor(AWSObject):
    """
    `Monitor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-internetmonitor-monitor.html>`__
    """

    resource_type = "AWS::InternetMonitor::Monitor"

    props: PropsDictType = {
        "HealthEventsConfig": (HealthEventsConfig, False),
        "InternetMeasurementsLogDelivery": (InternetMeasurementsLogDelivery, False),
        "MaxCityNetworksToMonitor": (integer, False),
        "MonitorName": (str, True),
        "Resources": ([str], False),
        "ResourcesToAdd": ([str], False),
        "ResourcesToRemove": ([str], False),
        "Status": (str, False),
        "Tags": (Tags, False),
        "TrafficPercentageToMonitor": (integer, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class AcknowledgeFlow(AWSProperty):
    """
    `AcknowledgeFlow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-acknowledgeflow.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
    }


class InitializationConfiguration(AWSProperty):
    """
    `InitializationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-initializationconfiguration.html>`__
    """

    props: PropsDictType = {
        "DisabledOnInitialization": (boolean, True),
    }


class AlarmCapabilities(AWSProperty):
    """
    `AlarmCapabilities <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-alarmcapabilities.html>`__
    """

    props: PropsDictType = {
        "AcknowledgeFlow": (AcknowledgeFlow, False),
        "InitializationConfiguration": (InitializationConfiguration, False),
    }


class Payload(AWSProperty):
    """
    `Payload <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-payload.html>`__
    """

    props: PropsDictType = {
        "ContentExpression": (str, True),
        "Type": (str, True),
    }


class DynamoDB(AWSProperty):
    """
    `DynamoDB <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-dynamodb.html>`__
    """

    props: PropsDictType = {
        "HashKeyField": (str, True),
        "HashKeyType": (str, False),
        "HashKeyValue": (str, True),
        "Operation": (str, False),
        "Payload": (Payload, False),
        "PayloadField": (str, False),
        "RangeKeyField": (str, False),
        "RangeKeyType": (str, False),
        "RangeKeyValue": (str, False),
        "TableName": (str, True),
    }


class DynamoDBv2(AWSProperty):
    """
    `DynamoDBv2 <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-dynamodbv2.html>`__
    """

    props: PropsDictType = {
        "Payload": (Payload, False),
        "TableName": (str, True),
    }


class Firehose(AWSProperty):
    """
    `Firehose <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-firehose.html>`__
    """

    props: PropsDictType = {
        "DeliveryStreamName": (str, True),
        "Payload": (Payload, False),
        "Separator": (str, False),
    }


class IotEvents(AWSProperty):
    """
    `IotEvents <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-iotevents.html>`__
    """

    props: PropsDictType = {
        "InputName": (str, True),
        "Payload": (Payload, False),
    }


class AssetPropertyTimestamp(AWSProperty):
    """
    `AssetPropertyTimestamp <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-assetpropertytimestamp.html>`__
    """

    props: PropsDictType = {
        "OffsetInNanos": (str, False),
        "TimeInSeconds": (str, True),
    }


class AssetPropertyVariant(AWSProperty):
    """
    `AssetPropertyVariant <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-assetpropertyvariant.html>`__
    """

    props: PropsDictType = {
        "BooleanValue": (str, False),
        "DoubleValue": (str, False),
        "IntegerValue": (str, False),
        "StringValue": (str, False),
    }


class AssetPropertyValue(AWSProperty):
    """
    `AssetPropertyValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-assetpropertyvalue.html>`__
    """

    props: PropsDictType = {
        "Quality": (str, False),
        "Timestamp": (AssetPropertyTimestamp, False),
        "Value": (AssetPropertyVariant, True),
    }


class IotSiteWise(AWSProperty):
    """
    `IotSiteWise <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-iotsitewise.html>`__
    """

    props: PropsDictType = {
        "AssetId": (str, False),
        "EntryId": (str, False),
        "PropertyAlias": (str, False),
        "PropertyId": (str, False),
        "PropertyValue": (AssetPropertyValue, True),
    }


class IotTopicPublish(AWSProperty):
    """
    `IotTopicPublish <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-iottopicpublish.html>`__
    """

    props: PropsDictType = {
        "MqttTopic": (str, True),
        "Payload": (Payload, False),
    }


class Lambda(AWSProperty):
    """
    `Lambda <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-lambda.html>`__
    """

    props: PropsDictType = {
        "FunctionArn": (str, True),
        "Payload": (Payload, False),
    }


class Sns(AWSProperty):
    """
    `Sns <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-sns.html>`__
    """

    props: PropsDictType = {
        "Payload": (Payload, False),
        "TargetArn": (str, True),
    }


class Sqs(AWSProperty):
    """
    `Sqs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-sqs.html>`__
    """

    props: PropsDictType = {
        "Payload": (Payload, False),
        "QueueUrl": (str, True),
        "UseBase64": (boolean, False),
    }


class AlarmAction(AWSProperty):
    """
    `AlarmAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-alarmaction.html>`__
    """

    props: PropsDictType = {
        "DynamoDB": (DynamoDB, False),
        "DynamoDBv2": (DynamoDBv2, False),
        "Firehose": (Firehose, False),
        "IotEvents": (IotEvents, False),
        "IotSiteWise": (IotSiteWise, False),
        "IotTopicPublish": (IotTopicPublish, False),
        "Lambda": (Lambda, False),
        "Sns": (Sns, False),
        "Sqs": (Sqs, False),
    }


class AlarmEventActions(AWSProperty):
    """
    `AlarmEventActions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-alarmeventactions.html>`__
    """

    props: PropsDictType = {
        "AlarmActions": ([AlarmAction], False),
    }


class SimpleRule(AWSProperty):
    """
    `SimpleRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-simplerule.html>`__
    """

    props: PropsDictType = {
        "ComparisonOperator": (str, True),
        "InputProperty": (str, True),
        "Threshold": (str, True),
    }


class AlarmRule(AWSProperty):
    """
    `AlarmRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-alarmmodel-alarmrule.html>`__
    """

    props: PropsDictType = {
        "SimpleRule": (SimpleRule, False),
    }


class AlarmModel(AWSObject):
    """
    `AlarmModel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotevents-alarmmodel.html>`__
    """

    resource_type = "AWS::IoTEvents::AlarmModel"

    props: PropsDictType = {
        "AlarmCapabilities": (AlarmCapabilities, False),
        "AlarmEventActions": (AlarmEventActions, False),
        "AlarmModelDescription": (str, False),
        "AlarmModelName": (str, False),
        "AlarmRule": (AlarmRule, True),
        "Key": (str, False),
        "RoleArn": (str, True),
        "Severity": (integer, False),
        "Tags": (Tags, False),
    }


class ClearTimer(AWSProperty):
    """
    `ClearTimer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-cleartimer.html>`__
    """

    props: PropsDictType = {
        "TimerName": (str, True),
    }


class ResetTimer(AWSProperty):
    """
    `ResetTimer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-resettimer.html>`__
    """

    props: PropsDictType = {
        "TimerName": (str, True),
    }


class SetTimer(AWSProperty):
    """
    `SetTimer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-settimer.html>`__
    """

    props: PropsDictType = {
        "DurationExpression": (str, False),
        "Seconds": (integer, False),
        "TimerName": (str, True),
    }


class SetVariable(AWSProperty):
    """
    `SetVariable <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-setvariable.html>`__
    """

    props: PropsDictType = {
        "Value": (str, True),
        "VariableName": (str, True),
    }


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-action.html>`__
    """

    props: PropsDictType = {
        "ClearTimer": (ClearTimer, False),
        "DynamoDB": (DynamoDB, False),
        "DynamoDBv2": (DynamoDBv2, False),
        "Firehose": (Firehose, False),
        "IotEvents": (IotEvents, False),
        "IotSiteWise": (IotSiteWise, False),
        "IotTopicPublish": (IotTopicPublish, False),
        "Lambda": (Lambda, False),
        "ResetTimer": (ResetTimer, False),
        "SetTimer": (SetTimer, False),
        "SetVariable": (SetVariable, False),
        "Sns": (Sns, False),
        "Sqs": (Sqs, False),
    }


class Event(AWSProperty):
    """
    `Event <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-event.html>`__
    """

    props: PropsDictType = {
        "Actions": ([Action], False),
        "Condition": (str, False),
        "EventName": (str, True),
    }


class OnEnter(AWSProperty):
    """
    `OnEnter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-onenter.html>`__
    """

    props: PropsDictType = {
        "Events": ([Event], False),
    }


class OnExit(AWSProperty):
    """
    `OnExit <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-onexit.html>`__
    """

    props: PropsDictType = {
        "Events": ([Event], False),
    }


class TransitionEvent(AWSProperty):
    """
    `TransitionEvent <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-transitionevent.html>`__
    """

    props: PropsDictType = {
        "Actions": ([Action], False),
        "Condition": (str, True),
        "EventName": (str, True),
        "NextState": (str, True),
    }


class OnInput(AWSProperty):
    """
    `OnInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-oninput.html>`__
    """

    props: PropsDictType = {
        "Events": ([Event], False),
        "TransitionEvents": ([TransitionEvent], False),
    }


class State(AWSProperty):
    """
    `State <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-state.html>`__
    """

    props: PropsDictType = {
        "OnEnter": (OnEnter, False),
        "OnExit": (OnExit, False),
        "OnInput": (OnInput, False),
        "StateName": (str, True),
    }


class DetectorModelDefinition(AWSProperty):
    """
    `DetectorModelDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-detectormodel-detectormodeldefinition.html>`__
    """

    props: PropsDictType = {
        "InitialStateName": (str, True),
        "States": ([State], True),
    }


class DetectorModel(AWSObject):
    """
    `DetectorModel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotevents-detectormodel.html>`__
    """

    resource_type = "AWS::IoTEvents::DetectorModel"

    props: PropsDictType = {
        "DetectorModelDefinition": (DetectorModelDefinition, True),
        "DetectorModelDescription": (str, False),
        "DetectorModelName": (str, False),
        "EvaluationMethod": (str, False),
        "Key": (str, False),
        "RoleArn": (str, True),
        "Tags": (Tags, False),
    }


class Attribute(AWSProperty):
    """
    `Attribute <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-input-attribute.html>`__
    """

    props: PropsDictType = {
        "JsonPath": (str, True),
    }


class InputDefinition(AWSProperty):
    """
    `InputDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotevents-input-inputdefinition.html>`__
    """

    props: PropsDictType = {
        "Attributes": ([Attribute], True),
    }


class Input(AWSObject):
    """
    `Input <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotevents-input.html>`__
    """

    resource_type = "AWS::IoTEvents::Input"

    props: PropsDictType = {
        "InputDefinition": (InputDefinition, True),
        "InputDescription": (str, False),
        "InputName": (str, False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean
from .validators.fms import validate_json_checker


class NotificationChannel(AWSObject):
    """
    `NotificationChannel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html>`__
    """

    resource_type = "AWS::FMS::NotificationChannel"

    props: PropsDictType = {
        "SnsRoleName": (str, True),
        "SnsTopicArn": (str, True),
    }


class IEMap(AWSProperty):
    """
    `IEMap <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html>`__
    """

    props: PropsDictType = {
        "ACCOUNT": ([str], False),
        "ORGUNIT": ([str], False),
    }


class NetworkFirewallPolicy(AWSProperty):
    """
    `NetworkFirewallPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html>`__
    """

    props: PropsDictType = {
        "FirewallDeploymentModel": (str, True),
    }


class ThirdPartyFirewallPolicy(AWSProperty):
    """
    `ThirdPartyFirewallPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-thirdpartyfirewallpolicy.html>`__
    """

    props: PropsDictType = {
        "FirewallDeploymentModel": (str, True),
    }


class PolicyOption(AWSProperty):
    """
    `PolicyOption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policyoption.html>`__
    """

    props: PropsDictType = {
        "NetworkFirewallPolicy": (NetworkFirewallPolicy, False),
        "ThirdPartyFirewallPolicy": (ThirdPartyFirewallPolicy, False),
    }


class SecurityServicePolicyData(AWSProperty):
    """
    `SecurityServicePolicyData <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-securityservicepolicydata.html>`__
    """

    props: PropsDictType = {
        "ManagedServiceData": (str, False),
        "PolicyOption": (PolicyOption, False),
        "Type": (str, True),
    }


class Policy(AWSObject):
    """
    `Policy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html>`__
    """

    resource_type = "AWS::FMS::Policy"

    props: PropsDictType = {
        "DeleteAllPolicyResources": (boolean, False),
        "ExcludeMap": (IEMap, False),
        "ExcludeResourceTags": (boolean, True),
        "IncludeMap": (IEMap, False),
        "PolicyDescription": (str, False),
        "PolicyName": (str, True),
        "RemediationEnabled": (boolean, True),
        "ResourceSetIds": ([str], False),
        "ResourceTags": (Tags, False),
        "ResourceType": (str, False),
        "ResourceTypeList": ([str], False),
        "ResourcesCleanUp": (boolean, False),
        "SecurityServicePolicyData": (validate_json_checker, True),
        "Tags": (Tags, False),
    }


class ResourceSet(AWSObject):
    """
    `ResourceSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-resourceset.html>`__
    """

    resource_type = "AWS::FMS::ResourceSet"

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "ResourceTypeList": ([str], True),
        "Resources": ([str], False),
        "Tags": (Tags, False),
    }



#!/usr/bin/python

import os
import unittest

import troposphere.ec2 as ec2
from troposphere import Base64, Join
from troposphere.helpers import userdata


class TestUserdata(unittest.TestCase):
    def setUp(self):
        self.instance = ec2.Instance("Instance", UserData="")
        dir = os.path.dirname(__file__)
        self.filepath = os.path.join(dir, "userdata_test_scripts/")

    def create_result(self, file, delimiter=""):
        file = os.path.join(self.filepath, file)
        self.instance.UserData = userdata.from_file(file, delimiter)
        return self.instance.UserData.to_dict()

    def create_answer(self, command_list, delimiter=""):
        return Base64(Join(delimiter, command_list)).to_dict()

    def test_simple(self):
        result = self.create_result("simple.sh")
        answer = self.create_answer(["#!/bin/bash\n", 'echo "Hello world"'])
        self.assertEqual(result, answer)

    def test_empty_file(self):
        result = self.create_result("empty.sh")
        answer = self.create_answer([])
        self.assertEqual(result, answer)

    def test_one_line_file(self):
        result = self.create_result("one_line.sh")
        answer = self.create_answer(["#!/bin/bash"])
        self.assertEqual(result, answer)

    def test_char_escaping(self):
        result = self.create_result("char_escaping.sh")
        answer = self.create_answer(
            [
                "\\n\n",
                "\\\n",
                "    \n",
                "?\n",
                '""\n',
                "\n",
                "<>\n",
            ]
        )

        self.assertEqual(result, answer)

    def test_nonexistant_file(self):
        self.assertRaises(IOError, self.create_result, "nonexistant.sh")


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, integer
from .validators.opsworkscm import validate_tags_or_list


class EngineAttribute(AWSProperty):
    """
    `EngineAttribute <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "Value": (str, False),
    }


class Server(AWSObject):
    """
    `Server <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html>`__
    """

    resource_type = "AWS::OpsWorksCM::Server"

    props: PropsDictType = {
        "AssociatePublicIpAddress": (boolean, False),
        "BackupId": (str, False),
        "BackupRetentionCount": (integer, False),
        "CustomCertificate": (str, False),
        "CustomDomain": (str, False),
        "CustomPrivateKey": (str, False),
        "DisableAutomatedBackup": (boolean, False),
        "Engine": (str, False),
        "EngineAttributes": ([EngineAttribute], False),
        "EngineModel": (str, False),
        "EngineVersion": (str, False),
        "InstanceProfileArn": (str, True),
        "InstanceType": (str, True),
        "KeyPair": (str, False),
        "PreferredBackupWindow": (str, False),
        "PreferredMaintenanceWindow": (str, False),
        "SecurityGroupIds": ([str], False),
        "ServiceRoleArn": (str, True),
        "SubnetIds": ([str], False),
        "Tags": (validate_tags_or_list, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import integer


class CloudWatchLogsDestinationConfiguration(AWSProperty):
    """
    `CloudWatchLogsDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivschat-loggingconfiguration-cloudwatchlogsdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "LogGroupName": (str, True),
    }


class FirehoseDestinationConfiguration(AWSProperty):
    """
    `FirehoseDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivschat-loggingconfiguration-firehosedestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "DeliveryStreamName": (str, True),
    }


class S3DestinationConfiguration(AWSProperty):
    """
    `S3DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivschat-loggingconfiguration-s3destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
    }


class DestinationConfiguration(AWSProperty):
    """
    `DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivschat-loggingconfiguration-destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogs": (CloudWatchLogsDestinationConfiguration, False),
        "Firehose": (FirehoseDestinationConfiguration, False),
        "S3": (S3DestinationConfiguration, False),
    }


class LoggingConfiguration(AWSObject):
    """
    `LoggingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivschat-loggingconfiguration.html>`__
    """

    resource_type = "AWS::IVSChat::LoggingConfiguration"

    props: PropsDictType = {
        "DestinationConfiguration": (DestinationConfiguration, True),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class MessageReviewHandler(AWSProperty):
    """
    `MessageReviewHandler <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivschat-room-messagereviewhandler.html>`__
    """

    props: PropsDictType = {
        "FallbackResult": (str, False),
        "Uri": (str, False),
    }


class Room(AWSObject):
    """
    `Room <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivschat-room.html>`__
    """

    resource_type = "AWS::IVSChat::Room"

    props: PropsDictType = {
        "LoggingConfigurationIdentifiers": ([str], False),
        "MaximumMessageLength": (integer, False),
        "MaximumMessageRatePerSecond": (integer, False),
        "MessageReviewHandler": (MessageReviewHandler, False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }



import unittest

from troposphere.dlm import CreateRule


class TestDlmCreateRule(unittest.TestCase):
    def test_createrule_interval_bad_value(self):
        with self.assertRaisesRegex(ValueError, "Interval must be one of"):
            CreateRule("CreateRule", Interval=25)

    def test_createrule_intervalunit_bad_value(self):
        with self.assertRaisesRegex(ValueError, "Interval unit must be one of"):
            CreateRule("CreateRule", Interval=24, IntervalUnit="HOUR")

    def test_createrule(self):
        CreateRule("CreateRule", Interval=24, IntervalUnit="HOURS")



import unittest

from troposphere import Ref, Tags, Template, ecs, iam


class TestDict(unittest.TestCase):
    def setUp(self):
        self.d = {
            "Cpu": 1,
            "Environment": [
                {"Name": "REGISTRY_STORAGE", "Value": "s3"},
                {"Name": "REGISTRY_STORAGE_S3_REGION", "Value": "eu-west-1"},
            ],
            "Essential": True,
            "Image": "registry:2",
            "Memory": 500,
            "Name": "registry",
            "PortMappings": [
                {"ContainerPort": 5000, "HostPort": 5000},
                {"ContainerPort": 5001, "HostPort": 5001},
            ],
            "Links": ["containerA", "containerB"],
        }

    def test_valid_data(self):
        t = Template()
        cd = ecs.ContainerDefinition.from_dict("mycontainer", self.d)
        self.assertEqual(cd.Links[0], "containerA")
        td = ecs.TaskDefinition(
            "taskdef",
            ContainerDefinitions=[cd],
            Volumes=[ecs.Volume(Name="myvol")],
            TaskRoleArn=Ref(iam.Role("myecsrole")),
        )
        t.add_resource(td)
        t.to_json()

    def test_invalid_toplevel_property(self):
        self.d["BlahInvalid"] = "Invalid"
        with self.assertRaises(AttributeError):
            ecs.ContainerDefinition.from_dict("mycontainer", self.d)

    def test_invalid_sub_property(self):
        self.d["Environment"][0]["BlahInvalid"] = "Invalid"
        with self.assertRaises(AttributeError):
            ecs.ContainerDefinition.from_dict("mycontainer", self.d)

    def test_toplevel_helper_fn(self):
        self.d["Cpu"] = Ref("MyCPU")
        cd = ecs.ContainerDefinition.from_dict("mycontainer", self.d)
        self.assertEqual(cd.Cpu.data, {"Ref": "MyCPU"})

    def test_sub_property_helper_fn(self):
        self.d["Environment"][0]["Value"] = Ref("RegistryStorage")
        cd = ecs.ContainerDefinition.from_dict("mycontainer", self.d)
        self.assertEqual(cd.Environment[0].Value.data, {"Ref": "RegistryStorage"})

    def test_invalid_subproperty_definition(self):
        self.d["Environment"][0] = "BadValue"
        with self.assertRaises(ValueError):
            ecs.ContainerDefinition.from_dict("mycontainer", self.d)

    def test_tags_from_dict(self):
        def key(k):
            return (k["Key"], k["Value"])

        d = {"key1": "value1", "key2": "value2"}
        expected = [{"Key": k, "Value": v} for k, v in d.items()]
        tags = Tags.from_dict(**d)

        self.assertEqual(sorted(expected, key=key), sorted(tags.tags, key=key))


if __name__ == "__main__":
    unittest.main()



import troposphere.ec2 as ec2
from troposphere import (
    Base64,
    GetAtt,
    Join,
    Output,
    Parameter,
    Ref,
    Tags,
    Template,
    cloudformation,
)

t = Template()

t.set_description("Configures an EC2 instance using cfn-init configsets")

key_name = t.add_parameter(
    Parameter(
        "KeyName",
        Type="AWS::EC2::KeyPair::KeyName",
        Description="Name of an existing EC2 KeyPair to enable SSH access",
    )
)

ami_id = t.add_parameter(Parameter("AmiId", Type="String", Default="ami-98aa1cf0"))

security_group = t.add_resource(
    ec2.SecurityGroup(
        "SecurityGroup",
        GroupDescription="Allows SSH access from anywhere",
        SecurityGroupIngress=[
            ec2.SecurityGroupRule(
                IpProtocol="tcp", FromPort=22, ToPort=22, CidrIp="0.0.0.0/0"
            )
        ],
        Tags=Tags(Name="ops.cfninit-sg"),
    )
)

ec2_instance = t.add_resource(
    ec2.Instance(
        "Ec2Instance",
        ImageId=Ref(ami_id),
        InstanceType="t1.micro",
        KeyName=Ref(key_name),
        SecurityGroups=[Ref(security_group)],
        IamInstanceProfile="PullCredentials",
        UserData=Base64(
            Join(
                "",
                [
                    "#!/bin/bash\n",
                    "sudo apt-get update\n",
                    "sudo apt-get -y install python-setuptools\n",
                    "sudo apt-get -y install python-pip\n",
                    "sudo pip install https://s3.amazonaws.com/cloudformation-examples/",
                    "aws-cfn-bootstrap-latest.tar.gz\n",
                    "cfn-init -s '",
                    Ref("AWS::StackName"),
                    "' -r Ec2Instance -c ascending",
                ],
            )
        ),
        Metadata=cloudformation.Metadata(
            cloudformation.Init(
                cloudformation.InitConfigSets(
                    ascending=["config1", "config2"], descending=["config2", "config1"]
                ),
                config1=cloudformation.InitConfig(
                    commands={
                        "test": {
                            "command": 'echo "$CFNTEST" > text.txt',
                            "env": {"CFNTEST": "I come from config1."},
                            "cwd": "~",
                        }
                    }
                ),
                config2=cloudformation.InitConfig(
                    commands={
                        "test": {
                            "command": 'echo "$CFNTEST" > text.txt',
                            "env": {"CFNTEST": "I come from config2."},
                            "cwd": "~",
                        }
                    }
                ),
            )
        ),
        Tags=Tags(Name="ops.cfninit", env="ops"),
    )
)

t.add_output(
    Output(
        "PublicIp",
        Description="Public IP of the newly created EC2 instance",
        Value=GetAtt(ec2_instance, "PublicIp"),
    )
)

print(t.to_json())



import io
import os
import re
import sys
import unittest


class TestExamples(unittest.TestCase):
    maxDiff = None

    # those are set by create_test_class
    filename = None
    expected_output = None

    def test_example(self):
        saved = sys.stdout
        stdout = io.StringIO()
        try:
            sys.stdout = stdout
            with open(self.filename) as f:
                code = compile(f.read(), self.filename, "exec")
                exec(code, {"__name__": "__main__"})
        finally:
            sys.stdout = saved
        # rewind fake stdout so we can read it
        stdout.seek(0)
        actual_output = stdout.read()
        self.assertEqual(str(self.expected_output), str(actual_output))


def create_test_class(testname, **kwargs):
    klass = type(testname, (TestExamples,), kwargs)
    return klass


def load_tests(loader, tests, pattern):
    # Filter out all *.py files from the examples directory
    examples = "examples"
    regex = re.compile(r".py$", re.I)
    example_filesnames = filter(regex.search, os.listdir(examples))

    suite = unittest.TestSuite()

    for f in example_filesnames:
        testname = "test_" + f[:-3]
        expected_output = open("tests/examples_output/%s.template" % f[:-3]).read()
        test_class = create_test_class(
            testname, filename=examples + "/" + f, expected_output=expected_output
        )
        tests = loader.loadTestsFromTestCase(test_class)
        suite.addTests(tests)

    return suite


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


def validate_tag_update(update):
    """
    Property: ResourceUpdateConstraint.TagUpdateOnProvisionedProduct
    """
    valid_tag_update_values = [
        "ALLOWED",
        "NOT_ALLOWED",
    ]
    if update not in valid_tag_update_values:
        raise ValueError("{} is not a valid tag update value".format(update))
    return update



# Copyright (c) 2022, Guy Taylor <thebigguy.co.uk@gmail.com>
# All rights reserved.
#
# See LICENSE file for full license.


def validate_flexibletimewindow_mode(flexibletimewindow_mode):
    """
    Validate State for FlexibleTimeWindow
    Property: FlexibleTimeWindow.Mode
    """

    valid_modes = ["OFF", "FLEXIBLE"]

    if flexibletimewindow_mode not in valid_modes:
        raise ValueError("{} is not a valid mode".format(flexibletimewindow_mode))
    return flexibletimewindow_mode


def validate_ecsparameters_tags(ecsparameters_tags):
    """
    Validate State for EcsParameters
    Property: EcsParameters.Tags
    """

    if ecsparameters_tags is not None:
        raise ValueError(
            "EcsParameters Tags must be None as the TagMap property is not currently supported by AWS CloudFormation"
        )
    return ecsparameters_tags



import unittest

from troposphere import If, Sub, Tag, Tags
from troposphere.autoscaling import Tags as ASTags


class TestTags(unittest.TestCase):
    def test_TagAddition(self):
        tags = Tags(foo="foo")
        tags += Tags(bar="bar")
        tags = tags + Tags(baz="baz")
        result = [
            {"Value": "foo", "Key": "foo"},
            {"Value": "bar", "Key": "bar"},
            {"Value": "baz", "Key": "baz"},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_TagConditional(self):
        tags = Tags(
            {"foo": "foo"}, If("MyCondition", Tag("bar", "bar"), Tag("baz", "baz"))
        )
        result = [
            {
                "Fn::If": [
                    "MyCondition",
                    {"Key": "bar", "Value": "bar"},
                    {"Key": "baz", "Value": "baz"},
                ]
            },
            {"Value": "foo", "Key": "foo"},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_ASTagAddition(self):
        tags = ASTags(foo=("fooval", True))
        tags += ASTags(bar=("barval", False))
        tags = tags + ASTags(baz="bazval")
        result = [
            {"Value": "fooval", "Key": "foo", "PropagateAtLaunch": True},
            {"Value": "barval", "Key": "bar", "PropagateAtLaunch": False},
            {"Value": "bazval", "Key": "baz", "PropagateAtLaunch": True},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_Unsortable(self):
        result = [{"Key": {"Fn::Sub": "somestring"}, "Value": "val"}]
        tags = Tags({Sub("somestring"): "val"})
        self.assertEqual(tags.to_dict(), result)

    def test_Formats(self):
        result = [
            {"Value": "bar", "Key": "bar"},
            {"Value": "baz", "Key": "baz"},
            {"Value": "foo", "Key": "foo"},
        ]
        tags = Tags(bar="bar", baz="baz", foo="foo")
        self.assertEqual(tags.to_dict(), result)
        tags = Tags({"bar": "bar", "baz": "baz", "foo": "foo"})
        self.assertEqual(tags.to_dict(), result)
        tags = Tags(**{"bar": "bar", "baz": "baz", "foo": "foo"})
        self.assertEqual(tags.to_dict(), result)
        result = [{"Key": "test-tag", "Value": "123456"}]
        tags = Tags({"test-tag": "123456"})
        self.assertEqual(tags.to_dict(), result)

        with self.assertRaises(TypeError):
            Tags(1)
        with self.assertRaises(TypeError):
            Tags("tag")
        with self.assertRaises(TypeError):
            Tags("key", "value")
        with self.assertRaises(TypeError):
            Tags({}, "key", "value")


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-channel.html>`__
    """

    resource_type = "AWS::MediaPackageV2::Channel"

    props: PropsDictType = {
        "ChannelGroupName": (str, False),
        "ChannelName": (str, False),
        "Description": (str, False),
        "Tags": (Tags, False),
    }


class ChannelGroup(AWSObject):
    """
    `ChannelGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-channelgroup.html>`__
    """

    resource_type = "AWS::MediaPackageV2::ChannelGroup"

    props: PropsDictType = {
        "ChannelGroupName": (str, False),
        "Description": (str, False),
        "Tags": (Tags, False),
    }


class ChannelPolicy(AWSObject):
    """
    `ChannelPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-channelpolicy.html>`__
    """

    resource_type = "AWS::MediaPackageV2::ChannelPolicy"

    props: PropsDictType = {
        "ChannelGroupName": (str, False),
        "ChannelName": (str, False),
        "Policy": (dict, True),
    }


class FilterConfiguration(AWSProperty):
    """
    `FilterConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-filterconfiguration.html>`__
    """

    props: PropsDictType = {
        "End": (str, False),
        "ManifestFilter": (str, False),
        "Start": (str, False),
        "TimeDelaySeconds": (integer, False),
    }


class ScteHls(AWSProperty):
    """
    `ScteHls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-sctehls.html>`__
    """

    props: PropsDictType = {
        "AdMarkerHls": (str, False),
    }


class HlsManifestConfiguration(AWSProperty):
    """
    `HlsManifestConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-hlsmanifestconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChildManifestName": (str, False),
        "FilterConfiguration": (FilterConfiguration, False),
        "ManifestName": (str, True),
        "ManifestWindowSeconds": (integer, False),
        "ProgramDateTimeIntervalSeconds": (integer, False),
        "ScteHls": (ScteHls, False),
        "Url": (str, False),
    }


class LowLatencyHlsManifestConfiguration(AWSProperty):
    """
    `LowLatencyHlsManifestConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-lowlatencyhlsmanifestconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChildManifestName": (str, False),
        "FilterConfiguration": (FilterConfiguration, False),
        "ManifestName": (str, True),
        "ManifestWindowSeconds": (integer, False),
        "ProgramDateTimeIntervalSeconds": (integer, False),
        "ScteHls": (ScteHls, False),
        "Url": (str, False),
    }


class EncryptionMethod(AWSProperty):
    """
    `EncryptionMethod <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-encryptionmethod.html>`__
    """

    props: PropsDictType = {
        "CmafEncryptionMethod": (str, False),
        "TsEncryptionMethod": (str, False),
    }


class EncryptionContractConfiguration(AWSProperty):
    """
    `EncryptionContractConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-encryptioncontractconfiguration.html>`__
    """

    props: PropsDictType = {
        "PresetSpeke20Audio": (str, True),
        "PresetSpeke20Video": (str, True),
    }


class SpekeKeyProvider(AWSProperty):
    """
    `SpekeKeyProvider <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-spekekeyprovider.html>`__
    """

    props: PropsDictType = {
        "DrmSystems": ([str], True),
        "EncryptionContractConfiguration": (EncryptionContractConfiguration, True),
        "ResourceId": (str, True),
        "RoleArn": (str, True),
        "Url": (str, True),
    }


class Encryption(AWSProperty):
    """
    `Encryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-encryption.html>`__
    """

    props: PropsDictType = {
        "ConstantInitializationVector": (str, False),
        "EncryptionMethod": (EncryptionMethod, True),
        "KeyRotationIntervalSeconds": (integer, False),
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class Scte(AWSProperty):
    """
    `Scte <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-scte.html>`__
    """

    props: PropsDictType = {
        "ScteFilter": ([str], False),
    }


class Segment(AWSProperty):
    """
    `Segment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-originendpoint-segment.html>`__
    """

    props: PropsDictType = {
        "Encryption": (Encryption, False),
        "IncludeIframeOnlyStreams": (boolean, False),
        "Scte": (Scte, False),
        "SegmentDurationSeconds": (integer, False),
        "SegmentName": (str, False),
        "TsIncludeDvbSubtitles": (boolean, False),
        "TsUseAudioRenditionGroup": (boolean, False),
    }


class OriginEndpoint(AWSObject):
    """
    `OriginEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpoint.html>`__
    """

    resource_type = "AWS::MediaPackageV2::OriginEndpoint"

    props: PropsDictType = {
        "ChannelGroupName": (str, False),
        "ChannelName": (str, False),
        "ContainerType": (str, True),
        "Description": (str, False),
        "HlsManifests": ([HlsManifestConfiguration], False),
        "LowLatencyHlsManifests": ([LowLatencyHlsManifestConfiguration], False),
        "OriginEndpointName": (str, False),
        "Segment": (Segment, False),
        "StartoverWindowSeconds": (integer, False),
        "Tags": (Tags, False),
    }


class OriginEndpointPolicy(AWSObject):
    """
    `OriginEndpointPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html>`__
    """

    resource_type = "AWS::MediaPackageV2::OriginEndpointPolicy"

    props: PropsDictType = {
        "ChannelGroupName": (str, False),
        "ChannelName": (str, False),
        "OriginEndpointName": (str, False),
        "Policy": (dict, True),
    }


class IngestEndpoint(AWSProperty):
    """
    `IngestEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackagev2-channel-ingestendpoint.html>`__
    """

    props: PropsDictType = {
        "Id": (str, False),
        "Url": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean


class DeviceUnderTest(AWSProperty):
    """
    `DeviceUnderTest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotcoredeviceadvisor-suitedefinition-deviceundertest.html>`__
    """

    props: PropsDictType = {
        "CertificateArn": (str, False),
        "ThingArn": (str, False),
    }


class SuiteDefinitionConfiguration(AWSProperty):
    """
    `SuiteDefinitionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iotcoredeviceadvisor-suitedefinition-suitedefinitionconfiguration.html>`__
    """

    props: PropsDictType = {
        "DevicePermissionRoleArn": (str, True),
        "Devices": ([DeviceUnderTest], False),
        "IntendedForQualification": (boolean, False),
        "RootGroup": (str, True),
        "SuiteDefinitionName": (str, False),
    }


class SuiteDefinition(AWSObject):
    """
    `SuiteDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotcoredeviceadvisor-suitedefinition.html>`__
    """

    resource_type = "AWS::IoTCoreDeviceAdvisor::SuiteDefinition"

    props: PropsDictType = {
        "SuiteDefinitionConfiguration": (SuiteDefinitionConfiguration, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from . import waf_action_type


def validate_waf_action_type(action):
    """
    Property: Action.Type
    """
    return waf_action_type(action)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer


class LogConfigurationForChannel(AWSProperty):
    """
    `LogConfigurationForChannel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-logconfigurationforchannel.html>`__
    """

    props: PropsDictType = {
        "LogTypes": ([str], False),
    }


class DashPlaylistSettings(AWSProperty):
    """
    `DashPlaylistSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-dashplaylistsettings.html>`__
    """

    props: PropsDictType = {
        "ManifestWindowSeconds": (double, False),
        "MinBufferTimeSeconds": (double, False),
        "MinUpdatePeriodSeconds": (double, False),
        "SuggestedPresentationDelaySeconds": (double, False),
    }


class HlsPlaylistSettings(AWSProperty):
    """
    `HlsPlaylistSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-hlsplaylistsettings.html>`__
    """

    props: PropsDictType = {
        "AdMarkupType": ([str], False),
        "ManifestWindowSeconds": (double, False),
    }


class RequestOutputItem(AWSProperty):
    """
    `RequestOutputItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-requestoutputitem.html>`__
    """

    props: PropsDictType = {
        "DashPlaylistSettings": (DashPlaylistSettings, False),
        "HlsPlaylistSettings": (HlsPlaylistSettings, False),
        "ManifestName": (str, True),
        "SourceGroup": (str, True),
    }


class SlateSource(AWSProperty):
    """
    `SlateSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-slatesource.html>`__
    """

    props: PropsDictType = {
        "SourceLocationName": (str, False),
        "VodSourceName": (str, False),
    }


class TimeShiftConfiguration(AWSProperty):
    """
    `TimeShiftConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-channel-timeshiftconfiguration.html>`__
    """

    props: PropsDictType = {
        "MaxTimeDelaySeconds": (double, True),
    }


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-channel.html>`__
    """

    resource_type = "AWS::MediaTailor::Channel"

    props: PropsDictType = {
        "ChannelName": (str, True),
        "FillerSlate": (SlateSource, False),
        "LogConfiguration": (LogConfigurationForChannel, False),
        "Outputs": ([RequestOutputItem], True),
        "PlaybackMode": (str, True),
        "Tags": (Tags, False),
        "Tier": (str, False),
        "TimeShiftConfiguration": (TimeShiftConfiguration, False),
    }


class ChannelPolicy(AWSObject):
    """
    `ChannelPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-channelpolicy.html>`__
    """

    resource_type = "AWS::MediaTailor::ChannelPolicy"

    props: PropsDictType = {
        "ChannelName": (str, True),
        "Policy": (dict, True),
    }


class HttpPackageConfiguration(AWSProperty):
    """
    `HttpPackageConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-vodsource-httppackageconfiguration.html>`__
    """

    props: PropsDictType = {
        "Path": (str, True),
        "SourceGroup": (str, True),
        "Type": (str, True),
    }


class LiveSource(AWSObject):
    """
    `LiveSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-livesource.html>`__
    """

    resource_type = "AWS::MediaTailor::LiveSource"

    props: PropsDictType = {
        "HttpPackageConfigurations": ([HttpPackageConfiguration], True),
        "LiveSourceName": (str, True),
        "SourceLocationName": (str, True),
        "Tags": (Tags, False),
    }


class AvailSuppression(AWSProperty):
    """
    `AvailSuppression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-availsuppression.html>`__
    """

    props: PropsDictType = {
        "Mode": (str, False),
        "Value": (str, False),
    }


class Bumper(AWSProperty):
    """
    `Bumper <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-bumper.html>`__
    """

    props: PropsDictType = {
        "EndUrl": (str, False),
        "StartUrl": (str, False),
    }


class CdnConfiguration(AWSProperty):
    """
    `CdnConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-cdnconfiguration.html>`__
    """

    props: PropsDictType = {
        "AdSegmentUrlPrefix": (str, False),
        "ContentSegmentUrlPrefix": (str, False),
    }


class DashConfiguration(AWSProperty):
    """
    `DashConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html>`__
    """

    props: PropsDictType = {
        "ManifestEndpointPrefix": (str, False),
        "MpdLocation": (str, False),
        "OriginManifestType": (str, False),
    }


class HlsConfiguration(AWSProperty):
    """
    `HlsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-hlsconfiguration.html>`__
    """

    props: PropsDictType = {
        "ManifestEndpointPrefix": (str, False),
    }


class LivePreRollConfiguration(AWSProperty):
    """
    `LivePreRollConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-liveprerollconfiguration.html>`__
    """

    props: PropsDictType = {
        "AdDecisionServerUrl": (str, False),
        "MaxDurationSeconds": (integer, False),
    }


class AdMarkerPassthrough(AWSProperty):
    """
    `AdMarkerPassthrough <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-admarkerpassthrough.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
    }


class ManifestProcessingRules(AWSProperty):
    """
    `ManifestProcessingRules <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-manifestprocessingrules.html>`__
    """

    props: PropsDictType = {
        "AdMarkerPassthrough": (AdMarkerPassthrough, False),
    }


class PlaybackConfiguration(AWSObject):
    """
    `PlaybackConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html>`__
    """

    resource_type = "AWS::MediaTailor::PlaybackConfiguration"

    props: PropsDictType = {
        "AdDecisionServerUrl": (str, True),
        "AvailSuppression": (AvailSuppression, False),
        "Bumper": (Bumper, False),
        "CdnConfiguration": (CdnConfiguration, False),
        "ConfigurationAliases": (dict, False),
        "DashConfiguration": (DashConfiguration, False),
        "HlsConfiguration": (HlsConfiguration, False),
        "LivePreRollConfiguration": (LivePreRollConfiguration, False),
        "ManifestProcessingRules": (ManifestProcessingRules, False),
        "Name": (str, True),
        "PersonalizationThresholdSeconds": (integer, False),
        "SlateAdUrl": (str, False),
        "Tags": (Tags, False),
        "TranscodeProfileName": (str, False),
        "VideoContentSourceUrl": (str, True),
    }


class SecretsManagerAccessTokenConfiguration(AWSProperty):
    """
    `SecretsManagerAccessTokenConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-sourcelocation-secretsmanageraccesstokenconfiguration.html>`__
    """

    props: PropsDictType = {
        "HeaderName": (str, False),
        "SecretArn": (str, False),
        "SecretStringKey": (str, False),
    }


class AccessConfiguration(AWSProperty):
    """
    `AccessConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-sourcelocation-accessconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccessType": (str, False),
        "SecretsManagerAccessTokenConfiguration": (
            SecretsManagerAccessTokenConfiguration,
            False,
        ),
    }


class DefaultSegmentDeliveryConfiguration(AWSProperty):
    """
    `DefaultSegmentDeliveryConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-sourcelocation-defaultsegmentdeliveryconfiguration.html>`__
    """

    props: PropsDictType = {
        "BaseUrl": (str, False),
    }


class HttpConfiguration(AWSProperty):
    """
    `HttpConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-sourcelocation-httpconfiguration.html>`__
    """

    props: PropsDictType = {
        "BaseUrl": (str, True),
    }


class SegmentDeliveryConfiguration(AWSProperty):
    """
    `SegmentDeliveryConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-sourcelocation-segmentdeliveryconfiguration.html>`__
    """

    props: PropsDictType = {
        "BaseUrl": (str, False),
        "Name": (str, False),
    }


class SourceLocation(AWSObject):
    """
    `SourceLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-sourcelocation.html>`__
    """

    resource_type = "AWS::MediaTailor::SourceLocation"

    props: PropsDictType = {
        "AccessConfiguration": (AccessConfiguration, False),
        "DefaultSegmentDeliveryConfiguration": (
            DefaultSegmentDeliveryConfiguration,
            False,
        ),
        "HttpConfiguration": (HttpConfiguration, True),
        "SegmentDeliveryConfigurations": ([SegmentDeliveryConfiguration], False),
        "SourceLocationName": (str, True),
        "Tags": (Tags, False),
    }


class VodSource(AWSObject):
    """
    `VodSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-vodsource.html>`__
    """

    resource_type = "AWS::MediaTailor::VodSource"

    props: PropsDictType = {
        "HttpPackageConfigurations": ([HttpPackageConfiguration], True),
        "SourceLocationName": (str, True),
        "Tags": (Tags, False),
        "VodSourceName": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class AgentPermissions(AWSProperty):
    """
    `AgentPermissions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html>`__
    """

    props: PropsDictType = {
        "Principals": ([str], True),
    }


class Channel(AWSProperty):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html>`__
    """

    props: PropsDictType = {
        "channelId": (str, False),
        "channelUri": (str, True),
    }


class ProfilingGroup(AWSObject):
    """
    `ProfilingGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html>`__
    """

    resource_type = "AWS::CodeGuruProfiler::ProfilingGroup"

    props: PropsDictType = {
        "AgentPermissions": (AgentPermissions, False),
        "AnomalyDetectionNotificationConfiguration": ([Channel], False),
        "ComputePlatform": (str, False),
        "ProfilingGroupName": (str, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType


class CognitoUserPoolConfiguration(AWSProperty):
    """
    `CognitoUserPoolConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-identitysource-cognitouserpoolconfiguration.html>`__
    """

    props: PropsDictType = {
        "ClientIds": ([str], False),
        "UserPoolArn": (str, True),
    }


class IdentitySourceConfiguration(AWSProperty):
    """
    `IdentitySourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-identitysource-identitysourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CognitoUserPoolConfiguration": (CognitoUserPoolConfiguration, True),
    }


class IdentitySource(AWSObject):
    """
    `IdentitySource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-verifiedpermissions-identitysource.html>`__
    """

    resource_type = "AWS::VerifiedPermissions::IdentitySource"

    props: PropsDictType = {
        "Configuration": (IdentitySourceConfiguration, True),
        "PolicyStoreId": (str, False),
        "PrincipalEntityType": (str, False),
    }


class StaticPolicyDefinition(AWSProperty):
    """
    `StaticPolicyDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policy-staticpolicydefinition.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "Statement": (str, True),
    }


class EntityIdentifier(AWSProperty):
    """
    `EntityIdentifier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policy-entityidentifier.html>`__
    """

    props: PropsDictType = {
        "EntityId": (str, True),
        "EntityType": (str, True),
    }


class TemplateLinkedPolicyDefinition(AWSProperty):
    """
    `TemplateLinkedPolicyDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policy-templatelinkedpolicydefinition.html>`__
    """

    props: PropsDictType = {
        "PolicyTemplateId": (str, True),
        "Principal": (EntityIdentifier, False),
        "Resource": (EntityIdentifier, False),
    }


class PolicyDefinition(AWSProperty):
    """
    `PolicyDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policy-policydefinition.html>`__
    """

    props: PropsDictType = {
        "Static": (StaticPolicyDefinition, False),
        "TemplateLinked": (TemplateLinkedPolicyDefinition, False),
    }


class Policy(AWSObject):
    """
    `Policy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-verifiedpermissions-policy.html>`__
    """

    resource_type = "AWS::VerifiedPermissions::Policy"

    props: PropsDictType = {
        "Definition": (PolicyDefinition, True),
        "PolicyStoreId": (str, True),
    }


class SchemaDefinition(AWSProperty):
    """
    `SchemaDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policystore-schemadefinition.html>`__
    """

    props: PropsDictType = {
        "CedarJson": (str, False),
    }


class ValidationSettings(AWSProperty):
    """
    `ValidationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-policystore-validationsettings.html>`__
    """

    props: PropsDictType = {
        "Mode": (str, True),
    }


class PolicyStore(AWSObject):
    """
    `PolicyStore <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-verifiedpermissions-policystore.html>`__
    """

    resource_type = "AWS::VerifiedPermissions::PolicyStore"

    props: PropsDictType = {
        "Description": (str, False),
        "Schema": (SchemaDefinition, False),
        "ValidationSettings": (ValidationSettings, True),
    }


class PolicyTemplate(AWSObject):
    """
    `PolicyTemplate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-verifiedpermissions-policytemplate.html>`__
    """

    resource_type = "AWS::VerifiedPermissions::PolicyTemplate"

    props: PropsDictType = {
        "Description": (str, False),
        "PolicyStoreId": (str, False),
        "Statement": (str, True),
    }


class IdentitySourceDetails(AWSProperty):
    """
    `IdentitySourceDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-verifiedpermissions-identitysource-identitysourcedetails.html>`__
    """

    props: PropsDictType = {
        "ClientIds": ([str], False),
        "DiscoveryUrl": (str, False),
        "OpenIdIssuer": (str, False),
        "UserPoolArn": (str, False),
    }



import unittest

import troposphere.opensearchservice as opensearchservice


class TestOpenSearchServiceValidators(unittest.TestCase):
    def test_validate_search_service_engine_version(self):
        valid_values = [
            "OpenSearch_1.1",
            "OpenSearch_10.123",
            "Elasticsearch_7.10",
            "Elasticsearch_6.5",
        ]
        for x in valid_values:
            opensearchservice.validate_search_service_engine_version(x)

        invalid_values = [
            "openSearch_1.1",
            "apenSearch_10.123",
            "elasticsearch_7.10",
            "Elasticsearch_x.x",
            "latest",
        ]
        for x in invalid_values:
            with self.assertRaises(ValueError):
                opensearchservice.validate_search_service_engine_version(x)



"""Protocols."""
from __future__ import annotations

from typing import Any, Dict

from .compat import Protocol


class JSONreprProtocol(Protocol):
    def JSONrepr(self, *__args: Any, **__kwargs: Any) -> Dict[str, Any]:
        raise NotImplementedError


class ToDictProtocol(Protocol):
    def to_dict(self) -> Dict[str, Any]:
        raise NotImplementedError



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double, integer
from .validators.transfer import validate_homedirectory_type


class Agreement(AWSObject):
    """
    `Agreement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-agreement.html>`__
    """

    resource_type = "AWS::Transfer::Agreement"

    props: PropsDictType = {
        "AccessRole": (str, True),
        "BaseDirectory": (str, True),
        "Description": (str, False),
        "LocalProfileId": (str, True),
        "PartnerProfileId": (str, True),
        "ServerId": (str, True),
        "Status": (str, False),
        "Tags": (Tags, False),
    }


class Certificate(AWSObject):
    """
    `Certificate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-certificate.html>`__
    """

    resource_type = "AWS::Transfer::Certificate"

    props: PropsDictType = {
        "ActiveDate": (str, False),
        "Certificate": (str, True),
        "CertificateChain": (str, False),
        "Description": (str, False),
        "InactiveDate": (str, False),
        "PrivateKey": (str, False),
        "Tags": (Tags, False),
        "Usage": (str, True),
    }


class As2Config(AWSProperty):
    """
    `As2Config <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-connector-as2config.html>`__
    """

    props: PropsDictType = {
        "BasicAuthSecretId": (str, False),
        "Compression": (str, False),
        "EncryptionAlgorithm": (str, False),
        "LocalProfileId": (str, False),
        "MdnResponse": (str, False),
        "MdnSigningAlgorithm": (str, False),
        "MessageSubject": (str, False),
        "PartnerProfileId": (str, False),
        "SigningAlgorithm": (str, False),
    }


class SftpConfig(AWSProperty):
    """
    `SftpConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-connector-sftpconfig.html>`__
    """

    props: PropsDictType = {
        "TrustedHostKeys": ([str], False),
        "UserSecretId": (str, False),
    }


class Connector(AWSObject):
    """
    `Connector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-connector.html>`__
    """

    resource_type = "AWS::Transfer::Connector"

    props: PropsDictType = {
        "AccessRole": (str, True),
        "As2Config": (As2Config, False),
        "LoggingRole": (str, False),
        "SftpConfig": (SftpConfig, False),
        "Tags": (Tags, False),
        "Url": (str, True),
    }


class Profile(AWSObject):
    """
    `Profile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-profile.html>`__
    """

    resource_type = "AWS::Transfer::Profile"

    props: PropsDictType = {
        "As2Id": (str, True),
        "CertificateIds": ([str], False),
        "ProfileType": (str, True),
        "Tags": (Tags, False),
    }


class EndpointDetails(AWSProperty):
    """
    `EndpointDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html>`__
    """

    props: PropsDictType = {
        "AddressAllocationIds": ([str], False),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
        "VpcEndpointId": (str, False),
        "VpcId": (str, False),
    }


class IdentityProviderDetails(AWSProperty):
    """
    `IdentityProviderDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-identityproviderdetails.html>`__
    """

    props: PropsDictType = {
        "DirectoryId": (str, False),
        "Function": (str, False),
        "InvocationRole": (str, False),
        "SftpAuthenticationMethods": (str, False),
        "Url": (str, False),
    }


class ProtocolDetails(AWSProperty):
    """
    `ProtocolDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-protocoldetails.html>`__
    """

    props: PropsDictType = {
        "As2Transports": ([str], False),
        "PassiveIp": (str, False),
        "SetStatOption": (str, False),
        "TlsSessionResumptionMode": (str, False),
    }


class S3StorageOptions(AWSProperty):
    """
    `S3StorageOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-s3storageoptions.html>`__
    """

    props: PropsDictType = {
        "DirectoryListingOptimization": (str, False),
    }


class WorkflowDetail(AWSProperty):
    """
    `WorkflowDetail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-workflowdetail.html>`__
    """

    props: PropsDictType = {
        "ExecutionRole": (str, True),
        "WorkflowId": (str, True),
    }


class WorkflowDetails(AWSProperty):
    """
    `WorkflowDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-workflowdetails.html>`__
    """

    props: PropsDictType = {
        "OnPartialUpload": ([WorkflowDetail], False),
        "OnUpload": ([WorkflowDetail], False),
    }


class Server(AWSObject):
    """
    `Server <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html>`__
    """

    resource_type = "AWS::Transfer::Server"

    props: PropsDictType = {
        "Certificate": (str, False),
        "Domain": (str, False),
        "EndpointDetails": (EndpointDetails, False),
        "EndpointType": (str, False),
        "IdentityProviderDetails": (IdentityProviderDetails, False),
        "IdentityProviderType": (str, False),
        "LoggingRole": (str, False),
        "PostAuthenticationLoginBanner": (str, False),
        "PreAuthenticationLoginBanner": (str, False),
        "ProtocolDetails": (ProtocolDetails, False),
        "Protocols": ([str], False),
        "S3StorageOptions": (S3StorageOptions, False),
        "SecurityPolicyName": (str, False),
        "StructuredLogDestinations": ([str], False),
        "Tags": (Tags, False),
        "WorkflowDetails": (WorkflowDetails, False),
    }


class HomeDirectoryMapEntry(AWSProperty):
    """
    `HomeDirectoryMapEntry <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-user-homedirectorymapentry.html>`__
    """

    props: PropsDictType = {
        "Entry": (str, True),
        "Target": (str, True),
        "Type": (str, False),
    }


class PosixProfile(AWSProperty):
    """
    `PosixProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-user-posixprofile.html>`__
    """

    props: PropsDictType = {
        "Gid": (double, True),
        "SecondaryGids": ([double], False),
        "Uid": (double, True),
    }


class User(AWSObject):
    """
    `User <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html>`__
    """

    resource_type = "AWS::Transfer::User"

    props: PropsDictType = {
        "HomeDirectory": (str, False),
        "HomeDirectoryMappings": ([HomeDirectoryMapEntry], False),
        "HomeDirectoryType": (validate_homedirectory_type, False),
        "Policy": (str, False),
        "PosixProfile": (PosixProfile, False),
        "Role": (str, True),
        "ServerId": (str, True),
        "SshPublicKeys": ([str], False),
        "Tags": (Tags, False),
        "UserName": (str, True),
    }


class S3InputFileLocation(AWSProperty):
    """
    `S3InputFileLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-s3inputfilelocation.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, False),
        "Key": (str, False),
    }


class S3FileLocation(AWSProperty):
    """
    `S3FileLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-s3filelocation.html>`__
    """

    props: PropsDictType = {
        "S3FileLocation": (S3InputFileLocation, False),
    }


class CopyStepDetails(AWSProperty):
    """
    `CopyStepDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-copystepdetails.html>`__
    """

    props: PropsDictType = {
        "DestinationFileLocation": (S3FileLocation, False),
        "Name": (str, False),
        "OverwriteExisting": (str, False),
        "SourceFileLocation": (str, False),
    }


class CustomStepDetails(AWSProperty):
    """
    `CustomStepDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-customstepdetails.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "SourceFileLocation": (str, False),
        "Target": (str, False),
        "TimeoutSeconds": (integer, False),
    }


class EfsInputFileLocation(AWSProperty):
    """
    `EfsInputFileLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-efsinputfilelocation.html>`__
    """

    props: PropsDictType = {
        "FileSystemId": (str, False),
        "Path": (str, False),
    }


class InputFileLocation(AWSProperty):
    """
    `InputFileLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-inputfilelocation.html>`__
    """

    props: PropsDictType = {
        "EfsFileLocation": (EfsInputFileLocation, False),
        "S3FileLocation": (S3InputFileLocation, False),
    }


class DecryptStepDetails(AWSProperty):
    """
    `DecryptStepDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-decryptstepdetails.html>`__
    """

    props: PropsDictType = {
        "DestinationFileLocation": (InputFileLocation, False),
        "Name": (str, False),
        "OverwriteExisting": (str, False),
        "SourceFileLocation": (str, False),
        "Type": (str, False),
    }


class DeleteStepDetails(AWSProperty):
    """
    `DeleteStepDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-deletestepdetails.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "SourceFileLocation": (str, False),
    }


class S3Tag(AWSProperty):
    """
    `S3Tag <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-s3tag.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Value": (str, True),
    }


class TagStepDetails(AWSProperty):
    """
    `TagStepDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-tagstepdetails.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "SourceFileLocation": (str, False),
        "Tags": ([S3Tag], False),
    }


class WorkflowStep(AWSProperty):
    """
    `WorkflowStep <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-workflow-workflowstep.html>`__
    """

    props: PropsDictType = {
        "CopyStepDetails": (CopyStepDetails, False),
        "CustomStepDetails": (CustomStepDetails, False),
        "DecryptStepDetails": (DecryptStepDetails, False),
        "DeleteStepDetails": (DeleteStepDetails, False),
        "TagStepDetails": (TagStepDetails, False),
        "Type": (str, False),
    }


class Workflow(AWSObject):
    """
    `Workflow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-workflow.html>`__
    """

    resource_type = "AWS::Transfer::Workflow"

    props: PropsDictType = {
        "Description": (str, False),
        "OnExceptionSteps": ([WorkflowStep], False),
        "Steps": ([WorkflowStep], True),
        "Tags": (Tags, False),
    }
